@@ -1,4 +1,5 @@
 import asyncio
+from typing import Callable
 
 from autogen_core.models import ChatCompletionClient
 
@@ -18,6 +19,7 @@ class SolverAgent(BaseGroupChatAgent):
             model_client: ChatCompletionClient,
             interface: Interface,
             usage_stats: dict,
+            save_logs_f: Callable,
             tester_agent_topic_type: str,
             return_next_time_possible_event: asyncio.Event
     ) -> None:
@@ -31,6 +33,7 @@ class SolverAgent(BaseGroupChatAgent):
             model_client=model_client,
             interface=interface,
             usage_stats=usage_stats,
+            save_logs_f=save_logs_f,
             return_next_time_possible_event=return_next_time_possible_event,
             next_agent_topic_types=[tester_agent_topic_type],
             max_internal_iterations=100,
