@@ -1,4 +1,5 @@
 import asyncio
+from typing import Callable
 
 from autogen_core.models import ChatCompletionClient
 
@@ -16,6 +17,7 @@ class SummarizerAgent(BaseGroupChatAgent):
             model_client: ChatCompletionClient,
             interface: Interface,
             usage_stats: dict,
+            save_logs_f: Callable,
             return_next_time_possible_event: asyncio.Event
     ) -> None:
 
@@ -26,6 +28,7 @@ class SummarizerAgent(BaseGroupChatAgent):
             model_client=model_client,
             interface=interface,
             usage_stats=usage_stats,
+            save_logs_f=save_logs_f,
             max_internal_iterations=10,
             return_next_time_possible_event=return_next_time_possible_event
         )
