@@ -37,9 +37,3 @@ class MaxOllamaRetrialsError(AgentError):
         super().__init__(agent_id,
                          f"Max ollama response errors retrials reached ({max_ollama_retrials})")
         self.max_ollama_retrials = max_ollama_retrials
-
-
-class TBTimeoutContainerDeletedError(AgentError):
-
-    def __init__(self, agent_id: str):
-        super().__init__(agent_id, f"TB timeout reached - tmux_session container not running anymore")
